@@ -62,7 +62,13 @@ def _make_tox_wheel(
         into = tmp_path_factory.mktemp("dist")  # pragma: no cover
         from tox.version import version_tuple  # noqa: PLC0415
 
-        version = f"{version_tuple[0]}.{version_tuple[1]}.{int(version_tuple[2]) + 1}"
+        patch_version = version_tuple[2]
+        if isinstance(patch_version, str) and patch_version[:3] == "dev":
+            # Version is in the form of 1.23.dev456, we need to increment the 456 part
+            version = f"{version_tuple[0]}.{version_tuple[1]}.dev{int(patch_version[3:]) + 1}"
+        else:
+            version = f"{version_tuple[0]}.{version_tuple[1]}.{int(patch_version) + 1}"
+
         with mock.patch.dict(os.environ, {"SETUPTOOLS_SCM_PRETEND_VERSION": version}):
             return pkg_builder(into, Path(__file__).parents[1], ["wheel"], False)  # pragma: no cover
 
@@ -81,14 +87,17 @@ def tox_wheels(tox_wheel: Path, tmp_path_factory: TempPathFactory) -> list[Path]
         distribution = Distribution.at(dist_info)
         wheel_cache = ROOT / ".wheel_cache" / f"{sys.version_info.major}.{sys.version_info.minor}"
         wheel_cache.mkdir(parents=True, exist_ok=True)
-        cmd = [sys.executable, "-I", "-m", "pip", "download", "-d", str(wheel_cache)]
+        cmd = [sys.executable, "-m", "pip", "download", "-d", str(wheel_cache)]
         assert distribution.requires is not None
         for req in distribution.requires:
             requirement = Requirement(req)
-            if not requirement.extras:  # pragma: no branch  # we don't need to install any extras (tests/docs/etc)
+            if not requirement.extras:  # pragma: no branch # we don't need to install any extras (tests/docs/etc)
                 cmd.append(req)
         check_call(cmd)
         result.extend(wheel_cache.iterdir())
+        res = "\n".join(str(i) for i in result)
+        with elapsed(f"acquired dependencies for current tox: {res}"):
+            pass
         return result
 
 
@@ -101,7 +110,7 @@ def pypi_index_self(pypi_server: IndexServer, tox_wheels: list[Path], demo_pkg_i
     return self_index
 
 
-@pytest.fixture()
+@pytest.fixture
 def _pypi_index_self(pypi_index_self: Index, monkeypatch: MonkeyPatch) -> None:
     pypi_index_self.use()
     monkeypatch.setenv("PIP_INDEX_URL", pypi_index_self.url)
@@ -121,7 +130,7 @@ def test_provision_requires_nok(tox_project: ToxProjectCreator) -> None:
     )
 
 
-@pytest.mark.integration()
+@pytest.mark.integration
 @pytest.mark.usefixtures("_pypi_index_self")
 def test_provision_requires_ok(tox_project: ToxProjectCreator, tmp_path: Path) -> None:
     proj = tox_project({"tox.ini": "[tox]\nrequires=demo-pkg-inline\n[testenv]\npackage=skip"})
@@ -154,7 +163,7 @@ def test_provision_requires_ok(tox_project: ToxProjectCreator, tmp_path: Path) -
     assert f"ROOT: remove tox env folder {provision_env}" in result_recreate.out, result_recreate.out
 
 
-@pytest.mark.integration()
+@pytest.mark.integration
 @pytest.mark.usefixtures("_pypi_index_self")
 def test_provision_platform_check(tox_project: ToxProjectCreator) -> None:
     ini = "[tox]\nrequires=demo-pkg-inline\n[testenv]\npackage=skip\n[testenv:.tox]\nplatform=wrong_platform"
@@ -188,7 +197,7 @@ def test_provision_no_recreate_json(tox_project: ToxProjectCreator) -> None:
     assert requires == {"minversion": None, "requires": ["p", "tox"]}
 
 
-@pytest.mark.integration()
+@pytest.mark.integration
 @pytest.mark.usefixtures("_pypi_index_self")
 @pytest.mark.parametrize("plugin_testenv", ["testenv", "testenv:a"])
 def test_provision_plugin_runner(tox_project: ToxProjectCreator, tmp_path: Path, plugin_testenv: str) -> None:
@@ -211,7 +220,7 @@ def test_provision_plugin_runner(tox_project: ToxProjectCreator, tmp_path: Path,
     assert prov_msg in result_label.out
 
 
-@pytest.mark.integration()
+@pytest.mark.integration
 def test_provision_plugin_runner_in_provision(tox_project: ToxProjectCreator, tmp_path: Path) -> None:
     """Ensure that provision environment can be explicitly configured."""
     log = tmp_path / "out.log"
@@ -220,7 +229,7 @@ def test_provision_plugin_runner_in_provision(tox_project: ToxProjectCreator, tm
         proj.run("r", "-e", "py", "--result-json", str(log))
 
 
-@pytest.mark.integration()
+@pytest.mark.integration
 @pytest.mark.usefixtures("_pypi_index_self")
 @pytest.mark.parametrize("relative_path", [True, False], ids=["relative", "absolute"])
 def test_provision_conf_file(tox_project: ToxProjectCreator, tmp_path: Path, relative_path: bool) -> None:
